==> 0.0.2.tar.gz: lib/src/models/table/table.dart <==
import 'package:json_annotation/json_annotation.dart';
import 'package:morph_dart/src/enums/field.dart';
import 'package:morph_dart/src/enums/table.dart';

part 'table.g.dart';

///==================================================================
/// Schema
///==================================================================
@JsonSerializable()
class TableObject {
  final String tableSlug;
  final String tableName;
  final TableType tableType;
  final List<FieldObject> fields;
  final TablePermission readPermission;
  final num? readMinStatus;
  final num? readMaxStatus;
  final TablePermission writePermission;
  final num? writeMinStatus;
  final num? writeMaxStatus;
  final String? comment;
  final String createdAt;
  final String? updatedAt;
  final String? deletedAt;

  const TableObject({
    required this.tableSlug,
    required this.tableName,
    required this.tableType,
    required this.fields,
    required this.readPermission,
    this.readMinStatus,
    this.readMaxStatus,
    required this.writePermission,
    this.writeMinStatus,
    this.writeMaxStatus,
    this.comment,
    required this.createdAt,
    this.updatedAt,
    this.deletedAt,
  });

  factory TableObject.fromJson(Map<String, dynamic> json) =>
      _$TableObjectFromJson(json);
}

@JsonSerializable()
class FieldObject {
  final String id;
  final String field;
  final FieldCategory category;
  final num? length;
  final bool? isUnsigned;
  final List<FieldOptionObject> options;
  final TableObject? linkedTable;
  final String? linkedTableSlug;
  final bool isNullable;
  final bool isUnique;
  final FieldEntitySetting? setting;
  final String? comment;

  const FieldObject({
    required this.id,
    required this.field,
    required this.category,
    this.length,
    this.isUnsigned,
    required this.options,
    this.linkedTable,
    this.linkedTableSlug,
    required this.isNullable,
    required this.isUnique,
    this.setting,
    this.comment,
  });

  factory FieldObject.fromJson(Map<String, dynamic> json) =>
      _$FieldObjectFromJson(json);
}

@JsonSerializable()
class FieldOptionObject {
  final String id;
  final String value;

  const FieldOptionObject({
    required this.id,
    required this.value,
  });

  factory FieldOptionObject.fromJson(Map<String, dynamic> json) =>
      _$FieldOptionObjectFromJson(json);
}

@JsonSerializable()
class FieldEntitySetting {
  final num? expirationTime;

  const FieldEntitySetting({
    this.expirationTime,
  });

  Map<String, dynamic> toJson() => _$FieldEntitySettingToJson(this);
  factory FieldEntitySetting.fromJson(Map<String, dynamic> json) =>
      _$FieldEntitySettingFromJson(json);
}

///==================================================================
/// Request Body
///==================================================================
@JsonSerializable()
class CreateTableRequestBody {
  final String tableSlug;
  final String tableName;
  final TableType tableType;
  final bool isEditable;
  final TablePermission readPermission;
  final num? readMinStatus;
  final num? readMaxStatus;
  final TablePermission writePermission;
  final num? writeMinStatus;
  final num? writeMaxStatus;
  final String? comment;

  const CreateTableRequestBody({
    required this.tableSlug,
    required this.tableName,
    required this.tableType,
    required this.isEditable,
    required this.readPermission,
    this.readMinStatus,
    this.readMaxStatus,
    required this.writePermission,
    this.writeMinStatus,
    this.writeMaxStatus,
    this.comment,
  });

  Map<String, dynamic> toJson() => _$CreateTableRequestBodyToJson(this);
}

@JsonSerializable()
class UpdateTableRequestBody {
  final String tableName;
  final String? newTableSlug;
  final TablePermission readPermission;
  final num? readMinStatus;
  final num? readMaxStatus;
  final TablePermission writePermission;
  final num? writeMinStatus;
  final num? writeMaxStatus;
  final String? comment;

  const UpdateTableRequestBody({
    required this.tableName,
    this.newTableSlug,
    required this.readPermission,
    this.readMinStatus,
    this.readMaxStatus,
    required this.writePermission,
    this.writeMinStatus,
    this.writeMaxStatus,
    this.comment,
  });

  Map<String, dynamic> toJson() => _$UpdateTableRequestBodyToJson(this);
}

///==================================================================
/// Response
///==================================================================
@JsonSerializable()
class TableResponse extends TableObject {
  const TableResponse({
    required String tableSlug,
    required String tableName,
    required TableType tableType,
    required List<FieldObject> fields,
    required TablePermission readPermission,
    num? readMinStatus,
    num? readMaxStatus,
    required TablePermission writePermission,
    num? writeMinStatus,
    num? writeMaxStatus,
    String? comment,
    required String createdAt,
    String? updatedAt,
    String? deletedAt,
  }) : super(
          tableSlug: tableSlug,
          tableName: tableName,
          tableType: tableType,
          fields: fields,
          readPermission: readPermission,
          readMinStatus: readMinStatus,
          readMaxStatus: readMaxStatus,
          writePermission: writePermission,
          writeMinStatus: writeMinStatus,
          writeMaxStatus: writeMaxStatus,
          comment: comment,
          createdAt: createdAt,
          updatedAt: updatedAt,
          deletedAt: deletedAt,
        );

  factory TableResponse.fromJson(Map<String, dynamic> json) =>
      _$TableResponseFromJson(json);
}

@JsonSerializable()
class TableListResponse {
  final List<TableObject> data;
  final num count;

  const TableListResponse({required this.data, required this.count});

  factory TableListResponse.fromJson(Map<String, dynamic> json) =>
      _$TableListResponseFromJson(json);
}

@JsonSerializable()
class CheckTableSlugResponse {
  final bool isAvailable;

  const CheckTableSlugResponse({
    required this.isAvailable,
  });

  factory CheckTableSlugResponse.fromJson(Map<String, dynamic> json) =>
      _$CheckTableSlugResponseFromJson(json);
}

==> 0.0.3-dev2.tar.gz: lib/src/models/table/table.dart <==
import 'package:json_annotation/json_annotation.dart';
import 'package:morph_dart/src/enums/field.dart';
import 'package:morph_dart/src/enums/table.dart';

part 'table.g.dart';

///==================================================================
/// Schema
///==================================================================
@JsonSerializable()
class TableObject {
  final String tableSlug;
  final String tableName;
  final TableType tableType;
  final List<FieldObject> fields;
  final TablePermission readPermission;
  final int? readMinStatus;
  final int? readMaxStatus;
  final TablePermission writePermission;
  final int? writeMinStatus;
  final int? writeMaxStatus;
  final String? comment;
  final String createdAt;
  final String? updatedAt;
  final String? deletedAt;

  const TableObject({
    required this.tableSlug,
    required this.tableName,
    required this.tableType,
    required this.fields,
    required this.readPermission,
    this.readMinStatus,
    this.readMaxStatus,
    required this.writePermission,
    this.writeMinStatus,
    this.writeMaxStatus,
    this.comment,
    required this.createdAt,
    this.updatedAt,
    this.deletedAt,
  });

  factory TableObject.fromJson(Map<String, dynamic> json) =>
      _$TableObjectFromJson(json);
}

@JsonSerializable()
class FieldObject {
  final String id;
  final String field;
  final FieldCategory category;
  final int? length;
  final bool? isUnsigned;
  final List<FieldOptionObject> options;
  final TableObject? linkedTable;
  final String? linkedTableSlug;
  final bool isNullable;
  final bool isUnique;
  final FieldEntitySetting? setting;
  final String? comment;

  const FieldObject({
    required this.id,
    required this.field,
    required this.category,
    this.length,
    this.isUnsigned,
    required this.options,
    this.linkedTable,
    this.linkedTableSlug,
    required this.isNullable,
    required this.isUnique,
    this.setting,
    this.comment,
  });

  factory FieldObject.fromJson(Map<String, dynamic> json) =>
      _$FieldObjectFromJson(json);
}

@JsonSerializable()
class FieldOptionObject {
  final String id;
  final String value;

  const FieldOptionObject({
    required this.id,
    required this.value,
  });

  factory FieldOptionObject.fromJson(Map<String, dynamic> json) =>
      _$FieldOptionObjectFromJson(json);
}

@JsonSerializable()
class FieldEntitySetting {
  final int? expirationTime;

  const FieldEntitySetting({
    this.expirationTime,
  });

  Map<String, dynamic> toJson() => _$FieldEntitySettingToJson(this);
  factory FieldEntitySetting.fromJson(Map<String, dynamic> json) =>
      _$FieldEntitySettingFromJson(json);
}

///==================================================================
/// Request Body
///==================================================================
@JsonSerializable()
class CreateTableRequestBody {
  final String tableSlug;
  final String tableName;
  final TableType tableType;
  final bool isEditable;
  final TablePermission readPermission;
  final int? readMinStatus;
  final int? readMaxStatus;
  final TablePermission writePermission;
  final int? writeMinStatus;
  final int? writeMaxStatus;
  final String? comment;

  const CreateTableRequestBody({
    required this.tableSlug,
    required this.tableName,
    required this.tableType,
    required this.isEditable,
    required this.readPermission,
    this.readMinStatus,
    this.readMaxStatus,
    required this.writePermission,
    this.writeMinStatus,
    this.writeMaxStatus,
    this.comment,
  });

  Map<String, dynamic> toJson() => _$CreateTableRequestBodyToJson(this);
}

@JsonSerializable()
class UpdateTableRequestBody {
  final String tableName;
  final String? newTableSlug;
  final TablePermission readPermission;
  final int? readMinStatus;
  final int? readMaxStatus;
  final TablePermission writePermission;
  final int? writeMinStatus;
  final int? writeMaxStatus;
  final String? comment;

  const UpdateTableRequestBody({
    required this.tableName,
    this.newTableSlug,
    required this.readPermission,
    this.readMinStatus,
    this.readMaxStatus,
    required this.writePermission,
    this.writeMinStatus,
    this.writeMaxStatus,
    this.comment,
  });

  Map<String, dynamic> toJson() => _$UpdateTableRequestBodyToJson(this);
}

///==================================================================
/// Response
///==================================================================
@JsonSerializable()
class TableResponse extends TableObject {
  const TableResponse({
    required String tableSlug,
    required String tableName,
    required TableType tableType,
    required List<FieldObject> fields,
    required TablePermission readPermission,
    int? readMinStatus,
    int? readMaxStatus,
    required TablePermission writePermission,
    int? writeMinStatus,
    int? writeMaxStatus,
    String? comment,
    required String createdAt,
    String? updatedAt,
    String? deletedAt,
  }) : super(
          tableSlug: tableSlug,
          tableName: tableName,
          tableType: tableType,
          fields: fields,
          readPermission: readPermission,
          readMinStatus: readMinStatus,
          readMaxStatus: readMaxStatus,
          writePermission: writePermission,
          writeMinStatus: writeMinStatus,
          writeMaxStatus: writeMaxStatus,
          comment: comment,
          createdAt: createdAt,
          updatedAt: updatedAt,
          deletedAt: deletedAt,
        );

  factory TableResponse.fromJson(Map<String, dynamic> json) =>
      _$TableResponseFromJson(json);
}

@JsonSerializable()
class TableListResponse {
  final List<TableObject> data;
  final int count;

  const TableListResponse({required this.data, required this.count});

  factory TableListResponse.fromJson(Map<String, dynamic> json) =>
      _$TableListResponseFromJson(json);
}

@JsonSerializable()
class CheckTableSlugResponse {
  final bool isAvailable;

  const CheckTableSlugResponse({
    required this.isAvailable,
  });

  factory CheckTableSlugResponse.fromJson(Map<String, dynamic> json) =>
      _$CheckTableSlugResponseFromJson(json);
}
